<?php

namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class AlteracaoAutomaticaDeParticularidadeController extends \Teknisa\GER\Controllers\TeknisaCrud
{

    protected $environment;

    public function __construct($crudService, $parameterBag, $environment)
    {
        parent::__construct($crudService, $parameterBag);
        $this->crudService       = $crudService;
        $this->environment       = $environment;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response)
    {
        $filterCriteria = $request->getFilterCriteria();
        $filterCriteria->addCondition("P_CDOPERADOR", $this->environment->getCdoperador());
        $conditions = $filterCriteria->getConditions();
        $dataset = $this->crudService->getFilteredDataSet("alteracaoautomaticadeparticularidade", $conditions)->getRows();
        $response->addDataSet(new DataSet("resp", $dataset));
    }

    public function confirmarWidget(Request\Row $request, Response $response)
    {
        $dataset       = $request->getRow();
        $arrayPosition = $dataset[0];
        $arrayGrid     = $dataset[1];
        $retorno = [];
        foreach ($arrayGrid as &$row) {
            if ($row['CDTIPPART'] == '1' || $row['CDTIPPART'] == '2' || $row['CDTIPPART'] == '3') {
                $arrayPosition['RESULT'] = $this->verificaMarca($arrayPosition, $row, $request, $response) ? '2' : '1';
                $arrayPosition['NMPRODUTO'] = $row['NMPRODUTO'];
            }
            if ($row['CDTIPPART'] == '4' || $row['CDTIPPART'] == '5' || $row['CDTIPPART'] == '6') {
                $arrayPosition['RESULT'] = $this->verificaFornecedor($arrayPosition, $row, $request, $response) ? '4' : '3';
                $arrayPosition['NMPRODUTO'] = $row['NMPRODUTO'];
            }
            if ($row['CDTIPPART'] == '7' || $row['CDTIPPART'] == '8' || $row['CDTIPPART'] == '9') {
                $arrayPosition['RESULT'] = $this->verificaMarcaFornecedor($arrayPosition, $row, $request, $response) ? '6' : '5';
                $arrayPosition['NMPRODUTO'] = $row['NMPRODUTO'];
            }
            array_push($retorno, $arrayPosition);
        }
        $response->addDataSet(new DataSet("resp", $retorno));
    }
    
    public function sqlBrand($arrayPosition, $row)
    {
        return $this->crudService->getFilteredDataSet("checkBrand", $this->criaFiltroMarca($arrayPosition, $row))->getRows(); 
    }
    
    public function criaFiltroMarca($arrayPosition, $row)
    {
        $filter = array(
		    array(
    		    "columnName" => "P_CDMARCA", 
    		    "operator" => "=",
    		    "value" => $arrayPosition['CDMARCA']
		    ),
    		array(
    		    "columnName" => "P_CDPRODUTO",
    		    "operator" => "=",
    		    "value" => $row['CDPRODUTO']
    		),
    		array(
    		    "columnName" => "P_NRORG", 
    		    "operator" => "=",
    		    "value" => $this->environment->getNrorg()
    		)
    	);
    	return $filter;
    }
    
    public function sqlForneced($arrayPosition, $row)
    {
        return $this->crudService->getFilteredDataSet("checkProvider", $this->criaFiltroFornecedor($arrayPosition, $row))->getRows(); 
    }
    
    public function criaFiltroFornecedor($arrayPosition, $row)
    {
        $filter = array(
		    array(
    		    "columnName" => "P_CDFORNECED", 
    		    "operator" => "=",
    		    "value" => $arrayPosition['CDFORNECED']
		    ),
    		array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "operator" => "=",
    		    "value" => $row['CDPRODUTO']
    		),
    		array(
    		    "columnName" => "P_NRORG", 
    		    "operator" => "=",
    		    "value" => $this->environment->getNrorg()
    		)
    	);
    	return $filter;
    }

    public function verificaMarca($arrayPosition, $row, $request, $response)
    {
        $verification = $this->sqlBrand($arrayPosition, $row);
        if (!empty($verification)) {
            $row['CDMARCA'] = $arrayPosition['CDMARCA'];
            $this->updatePartfili($row, $request, $response);
            return true;
        } else {
            return false;
        }
    }
    
    public function verificaFornecedor($arrayPosition, $row, $request, $response)
    {
        $verification = $this->sqlForneced($arrayPosition, $row);
        if (!empty($verification)) {
            $row['CDFORNECED'] = $arrayPosition['CDFORNECED'];
            $this->updatePartfili($row, $request, $response);
            return true;
        } else {
            return false;
        }
    }
    
    public function verificaMarcaFornecedor($arrayPosition, $row, $request, $response)
    {
        $verification = $this->sqlBrand($arrayPosition, $row);
        $verificationProvider = $this->sqlForneced($arrayPosition, $row);
        if (!empty($verification) && !empty($verificationProvider)) {
            $row['CDMARCA'] = $arrayPosition['CDMARCA'];
            $row['CDFORNECED'] = $arrayPosition['CDFORNECED'];
            $this->updatePartfili($row, $request, $response);
            return true;
        } else {
            return false;
        }
    }
    
    public function updatePartfili ($row, $request, $response)
    {
    	$this->dataSourceName = 'partfili';
        $row['__is_new'] = false;
        $requestToSave = new DTO\Request\Row($row, $request->getMethod(),$request->getRoutePath(), $request->getUserId());
        parent::save($requestToSave, $response);
    }
}
