<?php
namespace Modules\Cotacao\Modules\Pedido\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Util\SupUtilities;

class Sup09400 extends \Zeedhi\Framework\Controller\Report
{
    protected $birtStrategy;
    protected $environment;
    protected $reportService;
    protected $QR2Strategy;
    protected $supUtilities;
    protected $newCode;
    protected $entityManager;
    protected $connection;
    
    public function __construct($reportService, $birtStrategy, $environment, $QR2Strategy, $supUtilities,$newCode, $entityManager, $connection) {
        $this->reportService     = $reportService;
        $this->birtStrategy      = $birtStrategy;
        $this->environment       = $environment;
        $this->QR2Strategy       = $QR2Strategy;
        $this->supUtilities       = $supUtilities;
        $this->newCode             = $newCode;
        $this->entityManager     = $entityManager;
        $this->connection        = $connection;
    }
    
    /** @var array */
    protected $reportMapping = array (
        'SUP09400' =>
            array (
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array (
                        "CDFORNECED"     => "L_CDFORNECED",
                        "CDFILIAL"       => "L_CDFILIAL",
                        "NRPEDIDOCOL"    => "L_NRPEDIDOCOL",
                        "NRORG"          => "P_NRORG"
                    )
            ),
            'SUP09402' =>
            array (
                'strategy' => 'QR2',
                'parameterMapping' =>
                    array (
                        "CDFORNECED"     => "P_CDFORNECED",
                        "CDFILIAL"       => "P_CDFILIAL",
                        "NRPEDIDOCOL"    => "P_NRPEDIDOCOL"
                    )
            ),
            'SUP09410' =>
            array (
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array (
                        "CDFORNECED"     => "L_CDFORNECED",
                        "CDFILIAL"       => "L_CDFILIAL",
                        "NRPEDIDOCOL"    => "L_NRPEDIDOCOL",
                        "NRORG"          => "P_NRORG"
                    )
            )
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) 
    {
        $row = $request->getRow();
        if ($row['__report_name'] != 'SUP09402') {
            $row['CDFORNECED'] = $this->criarListaValores($row['CDFORNECED']);
            $row['CDFILIAL'] = $this->criarListaValores($row['CDFILIAL']);
            $row['NRPEDIDOCOL'] = $this->criarListaValores($row['NRPEDIDOCOL']);
        }
        if ($row['__report_name'] == 'SUP09400') {
            $idSisDos = $this->supUtilities->getIdSisDos();
            $row['__report_name'] = $idSisDos == 3 ? 'SUP09410' : 'SUP09400';
        }
        $row['NRORG'] = $this->environment->getNrorgTrab();
        $qr2type = isset($row['QR2TYPE']) ? $row['QR2TYPE'] : 'PDF';
        $this->birtStrategy->setReportFormat($qr2type);
        $this->QR2Strategy->setQr2Type($qr2type);
    }
    
    //cria lista de valores recebendo string como parametro
    public function criarListaValores($valores){
       
            $this->entityManager->beginTransaction();
            $lista = explode('_',$valores);
            $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
            try{
                foreach($lista as $key){
                    $this->insertLista($nrlista, $key);
                }
                $this->entityManager->commit();
                return $nrlista;
            } catch(\Exception $e){
                $this->entityManager->rollback();
                throw $e;
            }
        
    }
    //insere lista no banco
    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }

}