<?php
/**
 * Created by JetBrains PhpStorm.
 * User: alessandrobartel
 * Date: 29/06/12
 * Time: 10:37
 * To change this template use File | Settings | File Templates.
 */
 
class RegistroEmpregadoHomolognet extends RegistroHomolognet {

    const EMPREGADO = 'Empregado';
    const ENDERECO = 'Endereco';
    const CONTRATOS = 'Contratos';
    const CONTRATO = 'Contrato';

    const PIS_PASEP = 'NRPisPasep';
    const CPF = 'NRCpf';
    const NOME_EMPREGADO = 'NOEmpregado';
    const DATA_NASC = 'DTNascimento';
    const NOME_MAE = 'NOMae';

    const CEP = 'NRCep';
    const LOGRADOURO = 'EDLogradouro';
    const NUMERO = 'NREndereco';
    const COMPLEMENTO = 'DSComplemento';
    const BAIRRO = 'NOBairro';
    const MUNICIPIO = 'NOMunicipio';
    const UF = 'SGUF';

    const NUMERO_CTPS = 'NRCtps';
    const SERIE_CTPS = 'NRSerieCTPS';
    const UF_CTPS = 'SGUfCtps';


    private $_pessoa;

    private $_contratos;

    public function geraRegistroEmpregado(){
        $this->_geraRegistro();
    }

    private function _geraRegistro(){

        // Campo 16 - Tamanho 11 - PIS/PASEP do empregado
        $this->_atribuiPisPasep();

        // Campo 17 - Tamanho 11 - CPF do empregado
        $this->_atribuiCPF();

        // Campo 18 - Tamanho 150 - Nome do empregado
        $this->_atribuiNomeEmpregado();

        // Campo 19 - Tamanho 08 - Data de nascimento do empregado - AAAAMMDD
        $this->_atribuiDataNascimento();

//        // Campo 20 - Tamanho 150 - Nome da mae do empregado
//        $this->_atribuiNomeMae();

        // Atribuicao da tag Endereco
        $tag = self::ENDERECO;
        $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, null, 0);

        // Campo 21 - Tamanho 08 - CEP do endereco do empregado
        $this->_atribuiCEP();

        // Campo 22 - Tamanho 200 - Logradouro
        $this->_atribuiLogradouro();

        // Campo 23 - Tamanho 15 - Numero do endereco do empregado
        $this->_atribuiNumero();

        // Campo 24 - Tamanho 30 - Complemento do endereco do empregado
        $this->_atribuiComplemento();

        // Campo 25 - Tamanho 144 - Bairro do endereco do empregado
        $this->_atribuiBairro();

        // Campo 26 - Tamanho 144 - Municipio do endereco do empregado
        $this->_atribuiMunicipio();

        // Campo 27 - Tamanho 02 - UF do endereco do empregado
        $this->_atribuiUF();

        // Atribui tag de finalizacao de endereco
        $tag = parent::CARACTER_FINALIZADOR;
        $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, null, 0);

        // Campo 28 - Tamanho 07 - Numero da CTPS
        $this->_atribuiNumeroCTPS();

        // Campo 29 - Tamanho 05 - Serie da CTPS
        $this->_atribuiSerieCTPS();

        // Campo 30 - Tamanho 02 - UF sa CTPS
        $this->_atribuiUFCTPS();


        // Atribui tag de Contratos
        $this->_atribuiContratos();

    }

    public function setPessoa($pessoa) {
        $this->_pessoa = $pessoa;
    }

    public function setContratos($contratos){
        $this->_contratos = $contratos;
    }

    private function _atribuiPisPasep(){
    /* · Informar de acordo com o seguinte formato:99999999999
     * · Preencher este campo com a informação do número de inscrição no PIS (Programa de Integração Social) ou no
     *   PASEP (Programa de Formação do Patrimônio do Servidor Público) ou, ainda, com o Número de Identificação do
     *   Trabalhador – NIT.
     */
        $dado = $this->_pessoa->historico->getNrpispaseppes();
        if (empty($dado) === false) {
            $tag = self::PIS_PASEP.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 11);
        }
    }

    private function _atribuiCPF(){
    /* · Informar de acordo com o seguinte formato: 9999999999 */
        $dado = $this->_pessoa->historico->getNrcpfpessoa();
        if (empty($dado) === false) {
            $tag = self::CPF.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 11);
        }

    }

    private function _atribuiNomeEmpregado(){
        $dado = $this->_pessoa->historico->getNmpessoa();
        if (empty($dado) === false) {
            $tag = self::NOME_EMPREGADO.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 150);
        }
    }

    private function _atribuiDataNascimento(){
    /* · Informar de acordo com o seguinte formato: aaaammdd */
        $dataNascimento = new TkDateTime($this->_pessoa->historico->getDtnascpessoa());
        $dado = $dataNascimento->toString(TkDateTime::YEAR.TkDateTime::MONTH.TkDateTime::DAY);
        if (empty($dado) === false) {
            $tag = self::DATA_NASC.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 8);
        }
    }

    private function _atribuiNomeMae(){
        //@todo - A mae tambem eh uma pessoa. Verificar o relacionamento entre parceiros
        $dado = $this->_pessoa->nomeMae;
        if (empty($dado) === false) {
            $tag = self::NOME_MAE.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 150);
        }
    }

    private function _atribuiCEP(){
    /* · Informar de acordo com o seguinte formato: 9999999 */
        $dado = $this->_pessoa->cep;
        if (empty($dado) === false) {
            $tag = self::CEP.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 8);
        }
    }

    private function _atribuiLogradouro(){

        $dado = $this->_pessoa->endereco;
        if (empty($dado) === false) {
            $tag = self::LOGRADOURO.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 200);
        }
    }

    private function _atribuiNumero(){
        $dado = $this->_pessoa->numero;
        if (empty($dado) === false) {
            $tag = self::NUMERO.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 15);
        }
    }

    private function _atribuiComplemento(){
        $dado = $this->_pessoa->complemento;
        if (empty($dado) === false) {
            $tag = self::COMPLEMENTO.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 30);
        }
    }

    private function _atribuiBairro(){
        $dado = $this->_pessoa->bairro;
        if (empty($dado) === false) {
            $tag = self::BAIRRO.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 144);
        }
    }

    private function _atribuiMunicipio(){
        $dado = $this->_pessoa->municipio;
        if (empty($dado) === false) {
            $tag = self::MUNICIPIO.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 144);
        }
    }

    private function _atribuiUF(){
        $dado = $this->_pessoa->uf;
        if (empty($dado) === false) {
            $tag = self::UF.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 2);
        }
    }

    private function _atribuiNumeroCTPS(){
        $dado = $this->_pessoa->historico->getNrctpspessoa();
        if (empty($dado) === false) {
            $tag = self::NUMERO_CTPS.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 7);
        }
    }

    private function _atribuiSerieCTPS(){
        $dado = $this->_pessoa->historico->getNrseriectpspes();
        if (empty($dado) === false) {
            $tag = self::SERIE_CTPS.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 5);
        }
    }

    private function _atribuiUFCTPS(){
        $dado = $this->_pessoa->historico->getSgufctpspes();
        if (empty($dado) === false) {
            $tag = self::UF_CTPS.parent::CARACTER_ATRIBUI;
            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $dado, 2);
        }
    }

    private function _atribuiContratos(){

        $tag = self::CONTRATOS;
        $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, null, 0);

//        // Loop nos contratos
//        foreach ($this->_contratos as $contrato){
//
//            $tag = self::CONTRATO.parent::CARACTER_ATRIBUI;
//            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, $contrato, strlen($contrato));
//
//            $tag = parent::CARACTER_FINALIZADOR;
//            $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, null, 0);
//
//        }
//
        // Atribui tag de finalizacao de contratos
        $tag = parent::CARACTER_FINALIZADOR;
        $this->atribuiDadoXML($tag, parent::CARACTER_SEPARADOR, null, 0);

    }

}
